Compute the total causal effect between two variables from an adjacency matrix
Source:R/paths.r
calculate_total_effect.RdReturns the sum of all path effects enumerated by find_all_paths().
Returns 0 if no path exists.

R/paths.r
calculate_total_effect.RdReturns the sum of all path effects enumerated by find_all_paths().
Returns 0 if no path exists.